@@ -1,3 +1,4 @@
+"""Base class for the AutoML algorithms which power EvalML."""
 from abc import ABC, abstractmethod
 
 from evalml.exceptions import PipelineNotFoundError
@@ -5,20 +6,19 @@ from evalml.tuners import SKOptTuner
 
 
 class AutoMLAlgorithmException(Exception):
-    """Exception raised when an error is encountered during the computation of the automl algorithm"""
+    """Exception raised when an error is encountered during the computation of the automl algorithm."""
 
     pass
 
 
 class AutoMLAlgorithm(ABC):
-    """
-    Base class for the AutoML algorithms which power EvalML.
+    """Base class for the AutoML algorithms which power EvalML.
 
     This class represents an automated machine learning (AutoML) algorithm. It encapsulates the decision-making logic behind an automl search, by both deciding which pipelines to evaluate next and by deciding what set of parameters to configure the pipeline with.
 
     To use this interface, you must define a next_batch method which returns the next group of pipelines to evaluate on the training data. That method may access state and results recorded from the previous batches, although that information is not tracked in a general way in this base class. Overriding add_result is a convenient way to record pipeline evaluation info if necessary.
 
-    Arguments:
+    Args:
         allowed_pipelines (list(class)): A list of PipelineBase subclasses indicating the pipelines allowed in the search. The default of None indicates all pipelines for this problem type are allowed.
         custom_hyperparameters (dict): Custom hyperparameter ranges specified for pipelines to iterate over.
         max_iterations (int): The maximum number of iterations to be evaluated.
@@ -51,19 +51,22 @@ class AutoMLAlgorithm(ABC):
 
     @abstractmethod
     def next_batch(self):
-        """Get the next batch of pipelines to evaluate
+        """Get the next batch of pipelines to evaluate.
 
         Returns:
-            list(PipelineBase): a list of instances of PipelineBase subclasses, ready to be trained and evaluated.
+            list[PipelineBase]: A list of instances of PipelineBase subclasses, ready to be trained and evaluated.
         """
 
     def add_result(self, score_to_minimize, pipeline, trained_pipeline_results):
-        """Register results from evaluating a pipeline
+        """Register results from evaluating a pipeline.
 
-        Arguments:
+        Args:
             score_to_minimize (float): The score obtained by this pipeline on the primary objective, converted so that lower values indicate better pipelines.
             pipeline (PipelineBase): The trained pipeline object which was used to compute the score.
             trained_pipeline_results (dict): Results from training a pipeline.
+
+        Raises:
+            PipelineNotFoundError: If pipeline is not allowed in search.
         """
         if pipeline.name not in self._tuners:
             raise PipelineNotFoundError(
