@@ -1,3 +1,4 @@
+"""A Future-like api for jobs created by the SequentialEngine, an Engine that sequentially computes the submitted jobs."""
 from evalml.automl.engine.engine_base import (
     EngineBase,
     EngineComputation,
@@ -17,7 +18,7 @@ class SequentialComputation(EngineComputation):
     computation is "done", by always returning True in done() we make sure that get_result is called in the order that
     the jobs are submitted. So the computations happen sequentially!
 
-    Arguments:
+    Args:
         work (callable): Computation that should be done by the engine.
     """
 
@@ -27,14 +28,21 @@ class SequentialComputation(EngineComputation):
         self.meta_data = {}
 
     def done(self):
-        """Whether the computation is done."""
+        """Whether the computation is done.
+
+        Returns:
+            bool: Always returns True.
+        """
         return True
 
     def get_result(self):
-        """Gets the computation result.
-        Will block until the computation is finished.
+        """Gets the computation result. Will block until the computation is finished.
 
-        Raises Exception: If computation fails. Returns traceback.
+        Raises:
+            Exception: If computation fails. Returns traceback.
+
+        Returns:
+            Computation results.
         """
         return self.work(**self.kwargs)
 
@@ -43,9 +51,23 @@ class SequentialComputation(EngineComputation):
 
 
 class SequentialEngine(EngineBase):
-    """The default engine for the AutoML search. Trains and scores pipelines locally and sequentially."""
+    """The default engine for the AutoML search.
+
+    Trains and scores pipelines locally and sequentially.
+    """
 
     def submit_evaluation_job(self, automl_config, pipeline, X, y):
+        """Submit a job to evaluate a pipeline.
+
+        Args:
+            automl_config: Structure containing data passed from AutoMLSearch instance.
+            pipeline (pipeline.PipelineBase): Pipeline to evaluate.
+            X (pd.DataFrame): Input data for modeling.
+            y (pd.Series): Target data for modeling.
+
+        Returns:
+            SequentialComputation: Computation result.
+        """
         logger = self.setup_job_log()
         return SequentialComputation(
             work=evaluate_pipeline,
@@ -57,6 +79,17 @@ class SequentialEngine(EngineBase):
         )
 
     def submit_training_job(self, automl_config, pipeline, X, y):
+        """Submit a job to train a pipeline.
+
+        Args:
+            automl_config: Structure containing data passed from AutoMLSearch instance.
+            pipeline (pipeline.PipelineBase): Pipeline to evaluate.
+            X (pd.DataFrame): Input data for modeling.
+            y (pd.Series): Target data for modeling.
+
+        Returns:
+            SequentialComputation: Computation result.
+        """
         return SequentialComputation(
             work=train_pipeline,
             pipeline=pipeline,
@@ -67,6 +100,18 @@ class SequentialEngine(EngineBase):
         )
 
     def submit_scoring_job(self, automl_config, pipeline, X, y, objectives):
+        """Submit a job to score a pipeline.
+
+        Args:
+            automl_config: Structure containing data passed from AutoMLSearch instance.
+            pipeline (pipeline.PipelineBase): Pipeline to train.
+            X (pd.DataFrame): Input data for modeling.
+            y (pd.Series): Target data for modeling.
+            objectives (list[ObjectiveBase]): List of objectives to score on.
+
+        Returns:
+            SequentialComputation: Computation result.
+        """
         objectives = [get_objective(o, return_instance=True) for o in objectives]
         computation = SequentialComputation(
             work=score_pipeline,
@@ -81,4 +126,5 @@ class SequentialEngine(EngineBase):
         return computation
 
     def close(self):
+        """No-op."""
         pass
