@@ -1,3 +1,7 @@
+"""Data check that checks if any of the target labels are imbalanced, or if the number of values for each target are below 2 times the number of CV folds.
+
+Use for classification problems.
+"""
 from evalml.data_checks import (
     DataCheck,
     DataCheckError,
@@ -10,7 +14,7 @@ from evalml.utils import infer_feature_types
 class ClassImbalanceDataCheck(DataCheck):
     """Check if any of the target labels are imbalanced, or if the number of values for each target are below 2 times the number of CV folds. Use for classification problems.
 
-    Arguments:
+    Args:
         threshold (float): The minimum threshold allowed for class imbalance before a warning is raised.
             This threshold is calculated by comparing the number of samples in each class to the sum of samples in that class and the majority class.
             For example, a multiclass case with [900, 900, 100] samples per classes 0, 1, and 2, respectively,
@@ -42,10 +46,11 @@ class ClassImbalanceDataCheck(DataCheck):
         self.cv_folds = num_cv_folds * 2
 
     def validate(self, X, y):
-        """Checks if any target labels are imbalanced beyond a threshold for binary and multiclass problems
-            Ignores NaN values in target labels if they appear.
+        """Check if any target labels are imbalanced beyond a threshold for binary and multiclass problems.
 
-        Arguments:
+        Ignores NaN values in target labels if they appear.
+
+        Args:
             X (pd.DataFrame, np.ndarray): Features. Ignored.
             y (pd.Series, np.ndarray): Target labels to check for imbalanced data.
 
