@@ -1,7 +1,10 @@
+"""Recommended action returned by a DataCheck."""
+
+
 class DataCheckAction:
     """A recommended action returned by a DataCheck.
 
-    Arguments:
+    Args:
         action_code (DataCheckActionCode): Action code associated with the action.
         metadata (dict, optional): Additional useful information associated with the action. Defaults to None.
     """
@@ -11,9 +14,19 @@ class DataCheckAction:
         self.metadata = metadata or {}
 
     def __eq__(self, other):
-        """Checks for equality. Two DataCheckAction objs are considered equivalent if all of their attributes are equivalent."""
+        """Check for equality.
+
+        Two DataCheckAction objs are considered equivalent if all of their attributes are equivalent.
+
+        Args:
+            other: An object to compare equality with.
+
+        Returns:
+            bool: True if the other object is considered an equivalent data check action, False otherwise.
+        """
         return self.action_code == other.action_code and self.metadata == other.metadata
 
     def to_dict(self):
+        """Return a dictionary form of the data check action."""
         action_dict = {"code": self.action_code.name, "metadata": self.metadata}
         return action_dict
