@@ -1,3 +1,4 @@
+"""Data check that checks if the datetime column has equally spaced intervals and is monotonically increasing or decreasing in order to be supported by time series estimators."""
 import pandas as pd
 
 from evalml.data_checks import DataCheck, DataCheckError, DataCheckMessageCode
@@ -5,12 +6,10 @@ from evalml.utils import infer_feature_types
 
 
 class DateTimeFormatDataCheck(DataCheck):
-    """Checks if the datetime column has equally spaced intervals and is monotonically increasing or decreasing in order
-    to be supported by time series estimators.
+    """Check if the datetime column has equally spaced intervals and is monotonically increasing or decreasing in order to be supported by time series estimators.
 
-    Arguments:
+    Args:
         datetime_column (str, int): The name of the datetime column. If the datetime values are in the index, then pass "index".
-
     """
 
     def __init__(self, datetime_column="index"):
@@ -19,7 +18,7 @@ class DateTimeFormatDataCheck(DataCheck):
     def validate(self, X, y):
         """Checks if the target data has equal intervals and is sorted.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, np.ndarray): Features.
             y (pd.Series, np.ndarray): Target data.
 
