@@ -1,3 +1,5 @@
+"""Data check that checks each column in the input for datetime features and will issue an error if NaN values are present."""
+
 from evalml.data_checks import DataCheck, DataCheckError, DataCheckMessageCode
 from evalml.utils.woodwork_utils import infer_feature_types
 
@@ -5,12 +7,12 @@ error_contains_nan = "Input datetime column(s) ({}) contains NaN values. Please
 
 
 class DateTimeNaNDataCheck(DataCheck):
-    """Checks each column in the input for datetime features and will issue an error if NaN values are present."""
+    """Check each column in the input for datetime features and will issue an error if NaN values are present."""
 
     def validate(self, X, y=None):
-        """Checks if any datetime columns contain NaN values.
+        """Check if any datetime columns contain NaN values.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, np.ndarray): Features.
             y (pd.Series, np.ndarray): Ignored.  Defaults to None.
 
@@ -32,6 +34,7 @@ class DateTimeNaNDataCheck(DataCheck):
             ...                                                                     data_check_name=DateTimeNaNDataCheck.name,
             ...                                                                     message_code=DataCheckMessageCode.DATETIME_HAS_NAN,
             ...                                                                     details={"columns": 'index'}).to_dict()]}
+
         """
         results = {"warnings": [], "errors": [], "actions": []}
 
