@@ -1,3 +1,4 @@
+"""Data check that checks if any of the features are likely to be ID columns."""
 from evalml.data_checks import (
     DataCheck,
     DataCheckAction,
@@ -11,7 +12,7 @@ from evalml.utils import infer_feature_types
 class IDColumnsDataCheck(DataCheck):
     """Check if any of the features are likely to be ID columns.
 
-    Arguments:
+    Args:
         id_threshold (float): The probability threshold to be considered an ID column. Defaults to 1.0.
     """
 
@@ -21,14 +22,17 @@ class IDColumnsDataCheck(DataCheck):
         self.id_threshold = id_threshold
 
     def validate(self, X, y=None):
-        """Check if any of the features are likely to be ID columns. Currently performs these simple checks:
+        """Check if any of the features are likely to be ID columns. Currently performs a number of simple checks.
+
+        Checks performed are:
 
             - column name is "id"
             - column name ends in "_id"
             - column contains all unique values (and is categorical / integer type)
 
-        Arguments:
-            X (pd.DataFrame, np.ndarray): The input features to check
+        Args:
+            X (pd.DataFrame, np.ndarray): The input features to check.
+            y (pd.Series): The target. Defaults to None. Ignored.
 
         Returns:
             dict: A dictionary of features with column name or index and their probability of being ID columns
