@@ -1,3 +1,3 @@
-# flake8:noqas
+"""Family of machine learning models."""
 from .model_family import ModelFamily
 from .utils import handle_model_family
