@@ -1,3 +1,4 @@
+"""Model understanding graphing utilities."""
 import copy
 import os
 import warnings
@@ -42,9 +43,9 @@ from evalml.utils import import_or_raise, infer_feature_types, jupyter_check
 def confusion_matrix(y_true, y_predicted, normalize_method="true"):
     """Confusion matrix for binary and multiclass classification.
 
-    Arguments:
+    Args:
         y_true (pd.Series or np.ndarray): True binary labels.
-        y_pred (pd.Series or np.ndarray): Predictions from a binary classifier.
+        y_predicted (pd.Series or np.ndarray): Predictions from a binary classifier.
         normalize_method ({'true', 'pred', 'all', None}): Normalization method to use, if not None. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
 
     Returns:
@@ -65,12 +66,15 @@ def confusion_matrix(y_true, y_predicted, normalize_method="true"):
 def normalize_confusion_matrix(conf_mat, normalize_method="true"):
     """Normalizes a confusion matrix.
 
-    Arguments:
+    Args:
         conf_mat (pd.DataFrame or np.ndarray): Confusion matrix to normalize.
         normalize_method ({'true', 'pred', 'all'}): Normalization method. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
 
     Returns:
         pd.DataFrame: normalized version of the input confusion matrix. The column header represents the predicted labels while row header represents the actual labels.
+
+    Raises:
+        ValueError: If configuration is invalid, or if the sum of a given axis is zero and normalization by axis is specified.
     """
     conf_mat = infer_feature_types(conf_mat)
     col_names = conf_mat.columns
@@ -104,14 +108,14 @@ def graph_confusion_matrix(
 
     If `normalize_method` is set, hover text will show raw count, otherwise hover text will show count normalized with method 'true'.
 
-    Arguments:
+    Args:
         y_true (pd.Series or np.ndarray): True binary labels.
         y_pred (pd.Series or np.ndarray): Predictions from a binary classifier.
         normalize_method ({'true', 'pred', 'all', None}): Normalization method to use, if not None. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
-        title_addition (str or None): if not None, append to plot title. Defaults to None.
+        title_addition (str): If not None, append to plot title. Defaults to None.
 
     Returns:
-        plotly.Figure representing the confusion matrix plot generated
+        plotly.Figure representing the confusion matrix plot generated.
     """
     _go = import_or_raise(
         "plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects"
@@ -180,10 +184,9 @@ def graph_confusion_matrix(
 
 
 def precision_recall_curve(y_true, y_pred_proba, pos_label_idx=-1):
-    """
-    Given labels and binary classifier predicted probabilities, compute and return the data representing a precision-recall curve.
+    """Given labels and binary classifier predicted probabilities, compute and return the data representing a precision-recall curve.
 
-    Arguments:
+    Args:
         y_true (pd.Series or np.ndarray): True binary labels.
         y_pred_proba (pd.Series or np.ndarray): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
         pos_label_idx (int): the column index corresponding to the positive class. If predicted probabilities are two-dimensional, this will be used to access the probabilities for the positive class.
@@ -195,6 +198,9 @@ def precision_recall_curve(y_true, y_pred_proba, pos_label_idx=-1):
                   * `recall`: Recall values.
                   * `thresholds`: Threshold values used to produce the precision and recall.
                   * `auc_score`: The area under the ROC curve.
+
+    Raises:
+        NoPositiveLabelException: If predicted probabilities do not contain a column at the specified label.
     """
     y_true = infer_feature_types(y_true)
     y_pred_proba = infer_feature_types(y_pred_proba)
@@ -221,10 +227,10 @@ def precision_recall_curve(y_true, y_pred_proba, pos_label_idx=-1):
 def graph_precision_recall_curve(y_true, y_pred_proba, title_addition=None):
     """Generate and display a precision-recall plot.
 
-    Arguments:
+    Args:
         y_true (pd.Series or np.ndarray): True binary labels.
         y_pred_proba (pd.Series or np.ndarray): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
-        title_addition (str or None): If not None, append to plot title. Default None.
+        title_addition (str or None): If not None, append to plot title. Defaults to None.
 
     Returns:
         plotly.Figure representing the precision-recall plot generated
@@ -258,10 +264,9 @@ def graph_precision_recall_curve(y_true, y_pred_proba, title_addition=None):
 
 
 def roc_curve(y_true, y_pred_proba):
-    """
-    Given labels and classifier predicted probabilities, compute and return the data representing a Receiver Operating Characteristic (ROC) curve. Works with binary or multiclass problems.
+    """Given labels and classifier predicted probabilities, compute and return the data representing a Receiver Operating Characteristic (ROC) curve. Works with binary or multiclass problems.
 
-    Arguments:
+    Args:
         y_true (pd.Series or np.ndarray): True labels.
         y_pred_proba (pd.Series or np.ndarray): Predictions from a classifier, before thresholding has been applied.
 
@@ -310,14 +315,17 @@ def roc_curve(y_true, y_pred_proba):
 def graph_roc_curve(y_true, y_pred_proba, custom_class_names=None, title_addition=None):
     """Generate and display a Receiver Operating Characteristic (ROC) plot for binary and multiclass classification problems.
 
-    Arguments:
+    Args:
         y_true (pd.Series or np.ndarray): True labels.
         y_pred_proba (pd.Series or np.ndarray): Predictions from a classifier, before thresholding has been applied. Note this should a one dimensional array with the predicted probability for the "true" label in the binary case.
-        custom_class_labels (list or None): If not None, custom labels for classes. Default None.
-        title_addition (str or None): if not None, append to plot title. Default None.
+        custom_class_names (list or None): If not None, custom labels for classes. Defaults to None.
+        title_addition (str or None): if not None, append to plot title. Defaults to None.
 
     Returns:
         plotly.Figure representing the ROC plot generated
+
+    Raises:
+        ValueError: If the number of custom class names does not match number of classes in the input data.
     """
     _go = import_or_raise(
         "plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects"
@@ -369,15 +377,18 @@ def graph_roc_curve(y_true, y_pred_proba, custom_class_names=None, title_additio
 def graph_permutation_importance(pipeline, X, y, objective, importance_threshold=0):
     """Generate a bar graph of the pipeline's permutation importance.
 
-    Arguments:
-        pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame): The input data used to score and compute permutation importance
-        y (pd.Series): The target data
-        objective (str, ObjectiveBase): Objective to score on
-        importance_threshold (float, optional): If provided, graph features with a permutation importance whose absolute value is larger than importance_threshold. Defaults to zero.
+    Args:
+        pipeline (PipelineBase or subclass): Fitted pipeline.
+        X (pd.DataFrame): The input data used to score and compute permutation importance.
+        y (pd.Series): The target data.
+        objective (str, ObjectiveBase): Objective to score on.
+        importance_threshold (float, optional): If provided, graph features with a permutation importance whose absolute value is larger than importance_threshold. Defaults to 0.
 
     Returns:
         plotly.Figure, a bar graph showing features and their respective permutation importance.
+
+    Raises:
+        ValueError: If importance_threshold is not greater than or equal to 0.
     """
     go = import_or_raise(
         "plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects"
@@ -426,19 +437,21 @@ def graph_permutation_importance(pipeline, X, y, objective, importance_threshold
 
 
 def binary_objective_vs_threshold(pipeline, X, y, objective, steps=100):
-    """Computes objective score as a function of potential binary classification
-        decision thresholds for a fitted binary classification pipeline.
+    """Computes objective score as a function of potential binary classification decision thresholds for a fitted binary classification pipeline.
 
-    Arguments:
-        pipeline (BinaryClassificationPipeline obj): Fitted binary classification pipeline
-        X (pd.DataFrame): The input data used to compute objective score
-        y (pd.Series): The target labels
-        objective (ObjectiveBase obj, str): Objective used to score
-        steps (int): Number of intervals to divide and calculate objective score at
+    Args:
+        pipeline (BinaryClassificationPipeline obj): Fitted binary classification pipeline.
+        X (pd.DataFrame): The input data used to compute objective score.
+        y (pd.Series): The target labels.
+        objective (ObjectiveBase obj, str): Objective used to score.
+        steps (int): Number of intervals to divide and calculate objective score at.
 
     Returns:
-        pd.DataFrame: DataFrame with thresholds and the corresponding objective score calculated at each threshold
+        pd.DataFrame: DataFrame with thresholds and the corresponding objective score calculated at each threshold.
 
+    Raises:
+        ValueError: If objective is not a binary classification objective.
+        ValueError: If objective's `score_needs_proba` is not False.
     """
     objective = get_objective(objective, return_instance=True)
     if not objective.is_defined_for_problem_type(ProblemTypes.BINARY):
@@ -462,7 +475,7 @@ def binary_objective_vs_threshold(pipeline, X, y, objective, steps=100):
 def graph_binary_objective_vs_threshold(pipeline, X, y, objective, steps=100):
     """Generates a plot graphing objective score vs. decision thresholds for a fitted binary classification pipeline.
 
-    Arguments:
+    Args:
         pipeline (PipelineBase or subclass): Fitted pipeline
         X (pd.DataFrame): The input data used to score and compute scores
         y (pd.Series): The target labels
@@ -505,8 +518,7 @@ def _is_feature_of_type(feature, X, ltype):
 
 
 def _put_categorical_feature_first(features, first_feature_categorical):
-    """If the user is doing a two-way partial dependence plot and one of the features is categorical,
-    we need to make sure the categorical feature is the first element in the tuple that's passed to sklearn.
+    """If the user is doing a two-way partial dependence plot and one of the features is categorical, we need to ensure the categorical feature is the first element in the tuple that's passed to sklearn.
 
     This is because in the two-way grid calculation, sklearn will try to coerce every element of the grid to the
     type of the first feature in the tuple. If we put the categorical feature first, the grid will be of type 'object'
@@ -565,13 +577,13 @@ def _raise_value_error_if_mostly_one_value(df, percentile):
 def partial_dependence(
     pipeline, X, features, percentiles=(0.05, 0.95), grid_resolution=100, kind="average"
 ):
-    """Calculates one or two-way partial dependence.  If a single integer or
-    string is given for features, one-way partial dependence is calculated. If
-    a tuple of two integers or strings is given, two-way partial dependence
-    is calculated with the first feature in the y-axis and second feature in the
-    x-axis.
+    """Calculates one or two-way partial dependence.
 
-    Arguments:
+    If a single integer or string is given for features, one-way partial dependence is calculated. If
+    a tuple of two integers or strings is given, two-way partial dependence
+    is calculated with the first feature in the y-axis and second feature in the x-axis.
+
+    Args:
         pipeline (PipelineBase or subclass): Fitted pipeline
         X (pd.DataFrame, np.ndarray): The input data used to generate a grid of values
             for feature where partial dependence will be calculated at
@@ -584,7 +596,7 @@ def partial_dependence(
         grid_resolution (int): Number of samples of feature(s) for partial dependence plot.  If this value
             is less than the maximum number of categories present in categorical data within X, it will be
             set to the max number of categories + 1. Defaults to 100.
-        kind {'average', 'individual', 'both'}: The type of predictions to return. 'individual' will return the predictions for
+        kind ({'average', 'individual', 'both'}): The type of predictions to return. 'individual' will return the predictions for
             all of the points in the grid for each sample in X. 'average' will return the predictions for all of the points in
             the grid but averaged over all of the samples in X.
 
@@ -612,6 +624,8 @@ def partial_dependence(
             feature value pair.
 
     Raises:
+        ValueError: Error during call to scikit-learn's partial dependence method.
+        Exception: All other errors during calculation.
         PartialDependenceError: if the user provides a tuple of not exactly two features.
         PartialDependenceError: if the provided pipeline isn't fitted.
         PartialDependenceError: if the provided pipeline is a Baseline pipeline.
@@ -619,7 +633,6 @@ def partial_dependence(
         PartialDependenceError: if any of the features are low-variance. Defined as having one value occurring more than the upper
             percentile passed by the user. By default 95%.
     """
-
     try:
         # Dynamically set the grid resolution to the maximum number of values
         # in the categorical/datetime variables if there are more categories/datetime values than resolution cells
@@ -932,16 +945,17 @@ def _update_fig_with_two_way_partial_dependence(
 def graph_partial_dependence(
     pipeline, X, features, class_label=None, grid_resolution=100, kind="average"
 ):
-    """Create an one-way or two-way partial dependence plot.  Passing a single integer or
-    string as features will create a one-way partial dependence plot with the feature values
+    """Create an one-way or two-way partial dependence plot.
+
+    Passing a single integer or string as features will create a one-way partial dependence plot with the feature values
     plotted against the partial dependence.  Passing features a tuple of int/strings will create
     a two-way partial dependence plot with a contour of feature[0] in the y-axis, feature[1]
     in the x-axis and the partial dependence in the z-axis.
 
-    Arguments:
-        pipeline (PipelineBase or subclass): Fitted pipeline
+    Args:
+        pipeline (PipelineBase or subclass): Fitted pipeline.
         X (pd.DataFrame, np.ndarray): The input data used to generate a grid of values
-            for feature where partial dependence will be calculated at
+            for feature where partial dependence will be calculated at.
         features (int, string, tuple[int or string]): The target feature for which to create the partial dependence plot for.
             If features is an int, it must be the index of the feature to use.
             If features is a string, it must be a valid column name in X.
@@ -950,8 +964,8 @@ def graph_partial_dependence(
             the partial dependence for each class. This argument does not change behavior for regression or binary
             classification pipelines. For binary classification, the partial dependence for the positive label will
             always be displayed. Defaults to None.
-        grid_resolution (int): Number of samples of feature(s) for partial dependence plot
-        kind {'average', 'individual', 'both'}: Type of partial dependence to plot. 'average' creates a regular partial dependence
+        grid_resolution (int): Number of samples of feature(s) for partial dependence plot.
+        kind ({'average', 'individual', 'both'}): Type of partial dependence to plot. 'average' creates a regular partial dependence
              (PD) graph, 'individual' creates an individual conditional expectation (ICE) plot, and 'both' creates a
              single-figure PD and ICE plot. ICE plots can only be shown for one-way partial dependence plots.
 
@@ -1181,12 +1195,12 @@ def _calculate_axis_range(arr):
 def get_prediction_vs_actual_data(y_true, y_pred, outlier_threshold=None):
     """Combines y_true and y_pred into a single dataframe and adds a column for outliers. Used in `graph_prediction_vs_actual()`.
 
-    Arguments:
+    Args:
         y_true (pd.Series, or np.ndarray): The real target values of the data
         y_pred (pd.Series, or np.ndarray): The predicted values outputted by the regression model.
         outlier_threshold (int, float): A positive threshold for what is considered an outlier value. This value is compared to the absolute difference
                                  between each value of y_true and y_pred. Values within this threshold will be blue, otherwise they will be yellow.
-                                 Defaults to None
+                                 Defaults to None.
 
     Returns:
         pd.DataFrame with the following columns:
@@ -1194,6 +1208,8 @@ def get_prediction_vs_actual_data(y_true, y_pred, outlier_threshold=None):
                 * `actual`: Real target values.
                 * `outlier`: Colors indicating which values are in the threshold for what is considered an outlier value.
 
+    Raises:
+        ValueError: If threshold is not positive.
     """
     if outlier_threshold and outlier_threshold <= 0:
         raise ValueError(
@@ -1219,18 +1235,20 @@ def get_prediction_vs_actual_data(y_true, y_pred, outlier_threshold=None):
 
 
 def graph_prediction_vs_actual(y_true, y_pred, outlier_threshold=None):
-    """Generate a scatter plot comparing the true and predicted values. Used for regression plotting
+    """Generate a scatter plot comparing the true and predicted values. Used for regression plotting.
 
-    Arguments:
-        y_true (pd.Series): The real target values of the data
+    Args:
+        y_true (pd.Series): The real target values of the data.
         y_pred (pd.Series): The predicted values outputted by the regression model.
         outlier_threshold (int, float): A positive threshold for what is considered an outlier value. This value is compared to the absolute difference
                                  between each value of y_true and y_pred. Values within this threshold will be blue, otherwise they will be yellow.
-                                 Defaults to None
+                                 Defaults to None.
 
     Returns:
         plotly.Figure representing the predicted vs. actual values graph
 
+    Raises:
+        ValueError: If threshold is not positive.
     """
     _go = import_or_raise(
         "plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects"
@@ -1303,13 +1321,17 @@ def _tree_parse(est, feature_names):
 
 
 def decision_tree_data_from_estimator(estimator):
-    """Return data for a fitted tree in a restructured format
+    """Return data for a fitted tree in a restructured format.
 
-    Arguments:
+    Args:
         estimator (ComponentBase): A fitted DecisionTree-based estimator.
 
     Returns:
-        OrderedDict: An OrderedDict of OrderedDicts describing a tree structure
+        OrderedDict: An OrderedDict of OrderedDicts describing a tree structure.
+
+    Raises:
+        ValueError: If estimator is not a decision tree-based estimator.
+        NotFittedError: If estimator is not yet fitted.
     """
     if not estimator.model_family == ModelFamily.DECISION_TREE:
         raise ValueError(
@@ -1326,13 +1348,17 @@ def decision_tree_data_from_estimator(estimator):
 
 
 def decision_tree_data_from_pipeline(pipeline_):
-    """Return data for a fitted pipeline with  in a restructured format
+    """Return data for a fitted pipeline in a restructured format.
 
-    Arguments:
+    Args:
         pipeline_ (PipelineBase): A pipeline with a DecisionTree-based estimator.
 
     Returns:
-        OrderedDict: An OrderedDict of OrderedDicts describing a tree structure
+        OrderedDict: An OrderedDict of OrderedDicts describing a tree structure.
+
+    Raises:
+        ValueError: If estimator is not a decision tree-based estimator.
+        NotFittedError: If estimator is not yet fitted.
     """
     if not pipeline_.model_family == ModelFamily.DECISION_TREE:
         raise ValueError(
@@ -1352,20 +1378,21 @@ def decision_tree_data_from_pipeline(pipeline_):
 def visualize_decision_tree(
     estimator, max_depth=None, rotate=False, filled=False, filepath=None
 ):
-    """Generate an image visualizing the decision tree
+    """Generate an image visualizing the decision tree.
 
-    Arguments:
+    Args:
         estimator (ComponentBase): A fitted DecisionTree-based estimator.
-        max_depth (int, optional): The depth to which the tree should be displayed. If set to None (as by default),
-        tree is fully generated.
+        max_depth (int, optional): The depth to which the tree should be displayed. If set to None (as by default), tree is fully generated.
         rotate (bool, optional): Orient tree left to right rather than top-down.
-        filled (bool, optional): Paint nodes to indicate majority class for classification, extremity of values for
-        regression, or purity of node for multi-output.
-        filepath (str, optional): Path to where the graph should be saved. If set to None (as by default), the graph
-        will not be saved.
+        filled (bool, optional): Paint nodes to indicate majority class for classification, extremity of values for regression, or purity of node for multi-output.
+        filepath (str, optional): Path to where the graph should be saved. If set to None (as by default), the graph will not be saved.
 
     Returns:
         graphviz.Source: DOT object that can be directly displayed in Jupyter notebooks.
+
+    Raises:
+        ValueError: If estimator is not a decision tree-based estimator.
+        NotFittedError: If estimator is not yet fitted.
     """
     if not estimator.model_family == ModelFamily.DECISION_TREE:
         raise ValueError(
@@ -1430,7 +1457,7 @@ def visualize_decision_tree(
 def get_prediction_vs_actual_over_time_data(pipeline, X, y, X_train, y_train, dates):
     """Get the data needed for the prediction_vs_actual_over_time plot.
 
-    Arguments:
+    Args:
         pipeline (TimeSeriesRegressionPipeline): Fitted time series regression pipeline.
         X (pd.DataFrame): Features used to generate new predictions.
         y (pd.Series): Target values to compare predictions against.
@@ -1439,9 +1466,8 @@ def get_prediction_vs_actual_over_time_data(pipeline, X, y, X_train, y_train, da
         dates (pd.Series): Dates corresponding to target values and predictions.
 
     Returns:
-       pd.DataFrame
+        pd.DataFrame: Predictions vs. time.
     """
-
     dates = infer_feature_types(dates)
     prediction = pipeline.predict_in_sample(X, y, X_train=X_train, y_train=y_train)
 
@@ -1457,7 +1483,7 @@ def get_prediction_vs_actual_over_time_data(pipeline, X, y, X_train, y_train, da
 def graph_prediction_vs_actual_over_time(pipeline, X, y, X_train, y_train, dates):
     """Plot the target values and predictions against time on the x-axis.
 
-    Arguments:
+    Args:
         pipeline (TimeSeriesRegressionPipeline): Fitted time series regression pipeline.
         X (pd.DataFrame): Features used to generate new predictions.
         y (pd.Series): Target values to compare predictions against.
@@ -1467,6 +1493,9 @@ def graph_prediction_vs_actual_over_time(pipeline, X, y, X_train, y_train, dates
 
     Returns:
         plotly.Figure: Showing the prediction vs actual over time.
+
+    Raises:
+        ValueError: If the pipeline is not a time-series regression pipeline.
     """
     _go = import_or_raise(
         "plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects"
@@ -1511,12 +1540,16 @@ def graph_prediction_vs_actual_over_time(pipeline, X, y, X_train, y_train, dates
 def get_linear_coefficients(estimator, features=None):
     """Returns a dataframe showing the features with the greatest predictive power for a linear model.
 
-    Arguments:
+    Args:
         estimator (Estimator): Fitted linear model family estimator.
         features (list[str]): List of feature names associated with the underlying data.
 
     Returns:
         pd.DataFrame: Displaying the features by importance.
+
+    Raises:
+        ValueError: If the model is not a linear model.
+        NotFittedError: If the model is not yet fitted.
     """
     if not estimator.model_family == ModelFamily.LINEAR_MODEL:
         raise ValueError(
@@ -1547,17 +1580,19 @@ def t_sne(
 ):
     """Get the transformed output after fitting X to the embedded space using t-SNE.
 
-     Arguments:
+     Args:
         X (np.ndarray, pd.DataFrame): Data to be transformed. Must be numeric.
         n_components (int, optional): Dimension of the embedded space.
-        perplexity (float, optional): Related to the number of nearest neighbors that is used in other manifold learning
-        algorithms. Larger datasets usually require a larger perplexity. Consider selecting a value between 5 and 50.
-        learning_rate (float, optional): Usually in the range [10.0, 1000.0]. If the cost function gets stuck in a bad
-        local minimum, increasing the learning rate may help.
+        perplexity (float, optional): Related to the number of nearest neighbors that is used in other manifold learning algorithms. Larger datasets usually require a larger perplexity. Consider selecting a value between 5 and 50.
+        learning_rate (float, optional): Usually in the range [10.0, 1000.0]. If the cost function gets stuck in a bad local minimum, increasing the learning rate may help.
         metric (str, optional): The metric to use when calculating distance between instances in a feature array.
+        kwargs: Arbitrary keyword arguments.
 
     Returns:
-        np.ndarray (n_samples, n_components)
+        np.ndarray (n_samples, n_components): TSNE output.
+
+    Raises:
+        ValueError: If specified parameters are not valid values.
     """
     if not isinstance(n_components, int) or not n_components > 0:
         raise ValueError(
@@ -1588,22 +1623,23 @@ def graph_t_sne(
     marker_size=7,
     **kwargs,
 ):
-    """Plot high dimensional data into lower dimensional space using t-SNE .
+    """Plot high dimensional data into lower dimensional space using t-SNE.
 
-    Arguments:
+    Args:
         X (np.ndarray, pd.DataFrame): Data to be transformed. Must be numeric.
         n_components (int, optional): Dimension of the embedded space.
-        perplexity (float, optional): Related to the number of nearest neighbors that is used in other manifold learning
-        algorithms. Larger datasets usually require a larger perplexity. Consider selecting a value between 5 and 50.
-        learning_rate (float, optional): Usually in the range [10.0, 1000.0]. If the cost function gets stuck in a bad
-        local minimum, increasing the learning rate may help.
+        perplexity (float, optional): Related to the number of nearest neighbors that is used in other manifold learning algorithms. Larger datasets usually require a larger perplexity. Consider selecting a value between 5 and 50.
+        learning_rate (float, optional): Usually in the range [10.0, 1000.0]. If the cost function gets stuck in a bad local minimum, increasing the learning rate may help.
         metric (str, optional): The metric to use when calculating distance between instances in a feature array.
         marker_line_width (int, optional): Determines the line width of the marker boundary.
         marker_size (int, optional): Determines the size of the marker.
+        kwargs: Arbitrary keyword arguments.
 
     Returns:
-        plotly.Figure representing the transformed data
+        plotly.Figure: Figure representing the transformed data.
 
+    Raises:
+        ValueError: If marker_line_width or marker_size are not valid values.
     """
     _go = import_or_raise(
         "plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects"
