@@ -1,3 +1,4 @@
+"""Pipeline subclass for all binary classification pipelines."""
 from .binary_classification_pipeline_mixin import (
     BinaryClassificationPipelineMixin,
 )
@@ -13,7 +14,7 @@ class BinaryClassificationPipeline(
 ):
     """Pipeline subclass for all binary classification pipelines.
 
-    Arguments:
+    Args:
         component_graph (list or dict): List of components in order. Accepts strings or ComponentBase subclasses in the list.
             Note that when duplicate components are specified in a list, the duplicate component names will be modified with the
             component's index in the list. For example, the component graph
@@ -31,14 +32,13 @@ class BinaryClassificationPipeline(
     def _predict(self, X, objective=None):
         """Make predictions using selected features.
 
-        Arguments:
+        Args:
             X (pd.DataFrame): Data of shape [n_samples, n_features]
-            objective (Object or string): The objective to use to make predictions
+            objective (Object or string): The objective to use to make predictions.
 
         Returns:
             pd.Series: Estimated labels
         """
-
         if objective is not None:
             objective = get_objective(objective, return_instance=True)
             if not objective.is_defined_for_problem_type(self.problem_type):
@@ -55,7 +55,7 @@ class BinaryClassificationPipeline(
     def predict_proba(self, X, X_train=None, y_train=None):
         """Make probability estimates for labels. Assumes that the column at index 1 represents the positive label case.
 
-        Arguments:
+        Args:
             X (pd.DataFrame or np.ndarray): Data of shape [n_samples, n_features]
             X_train (pd.DataFrame or np.ndarray or None): Training data. Ignored. Only used for time series.
             y_train (pd.Series or None): Training labels. Ignored. Only used for time series.
