@@ -1,4 +1,9 @@
+"""Binary classification pipeline mix-in class."""
+
+
 class BinaryClassificationPipelineMixin:
+    """Binary classification pipeline mix-in class."""
+
     _threshold = None
 
     @property
@@ -39,11 +44,14 @@ class BinaryClassificationPipelineMixin:
     def optimize_threshold(self, X, y, y_pred_proba, objective):
         """Optimize the pipeline threshold given the objective to use. Only used for binary problems with objectives whose thresholds can be tuned.
 
-        Arguments:
-            X (pd.DataFrame): Input features
-            y (pd.Series): Input target values
-            y_pred_proba (pd.Series): The predicted probabilities of the target outputted by the pipeline
+        Args:
+            X (pd.DataFrame): Input features.
+            y (pd.Series): Input target values.
+            y_pred_proba (pd.Series): The predicted probabilities of the target outputted by the pipeline.
             objective (ObjectiveBase): The objective to threshold with. Must have a tunable threshold.
+
+        Raises:
+            ValueError: If objective is not optimizable.
         """
         if self.can_tune_threshold_with_objective(objective):
             targets = self._encode_targets(y)
