@@ -1,4 +1,4 @@
-# flake8:noqa
+"""Ensemble components."""
 from .sklearn_stacked_ensemble_base import SklearnStackedEnsembleBase
 from .sklearn_stacked_ensemble_classifier import SklearnStackedEnsembleClassifier
 from .sklearn_stacked_ensemble_regressor import SklearnStackedEnsembleRegressor
