@@ -1,3 +1,4 @@
+"""XGBoost Classifier."""
 import numpy as np
 import pandas as pd
 from pandas.api.types import is_integer_dtype
@@ -15,10 +16,9 @@ from evalml.utils import (
 
 
 class XGBoostClassifier(Estimator):
-    """
-    XGBoost Classifier.
+    """XGBoost Classifier.
 
-    Arguments:
+    Args:
         eta (float): Boosting learning rate. Defaults to 0.1.
         max_depth (int): Maximum tree depth for base learners. Defaults to 6.
         min_child_weight (float): Minimum sum of instance weight (hessian) needed in a child. Defaults to 1.0
@@ -107,6 +107,15 @@ class XGBoostClassifier(Estimator):
         return y
 
     def fit(self, X, y=None):
+        """Fits XGBoost classifier component to data.
+
+        Args:
+            X (pd.DataFrame): The input training data of shape [n_samples, n_features].
+            y (pd.Series): The target training data of length [n_samples].
+
+        Returns:
+            self
+        """
         X, y = super()._manage_woodwork(X, y)
         X.ww.set_types(self._convert_bool_to_int(X))
         self.input_feature_names = list(X.columns)
@@ -116,6 +125,14 @@ class XGBoostClassifier(Estimator):
         return self
 
     def predict(self, X):
+        """Make predictions using the fitted XGBoost classifier.
+
+        Args:
+            X (pd.DataFrame): Data of shape [n_samples, n_features].
+
+        Returns:
+            pd.DataFrame: Predicted values.
+        """
         X, _ = super()._manage_woodwork(X)
         X.ww.set_types(self._convert_bool_to_int(X))
         X = _rename_column_names_to_numeric(X, flatten_tuples=False)
@@ -128,6 +145,14 @@ class XGBoostClassifier(Estimator):
         return infer_feature_types(predictions)
 
     def predict_proba(self, X):
+        """Make predictions using the fitted CatBoost classifier.
+
+        Args:
+            X (pd.DataFrame): Data of shape [n_samples, n_features].
+
+        Returns:
+            pd.DataFrame: Predicted values.
+        """
         X, _ = super()._manage_woodwork(X)
         X.ww.set_types(self._convert_bool_to_int(X))
         X = _rename_column_names_to_numeric(X, flatten_tuples=False)
@@ -135,4 +160,5 @@ class XGBoostClassifier(Estimator):
 
     @property
     def feature_importance(self):
+        """Feature importance of fitted XGBoost classifier."""
         return self._component_obj.feature_importances_
