@@ -1,3 +1,4 @@
+"""Decision Tree Regressor."""
 from sklearn.tree import DecisionTreeRegressor as SKDecisionTreeRegressor
 from skopt.space import Integer
 
@@ -7,10 +8,9 @@ from evalml.problem_types import ProblemTypes
 
 
 class DecisionTreeRegressor(Estimator):
-    """
-    Decision Tree Regressor.
+    """Decision Tree Regressor.
 
-    Arguments:
+    Args:
         criterion ({"mse", "friedman_mse", "mae", "poisson"}): The function to measure the quality of a split.
             Supported criteria are:
 
