@@ -1,3 +1,4 @@
+"""Featuretools DFS component that generates features for the input features."""
 from featuretools import EntitySet, calculate_feature_matrix, dfs
 
 from evalml.pipelines.components.transformers.transformer import Transformer
@@ -10,7 +11,7 @@ from evalml.utils import (
 class DFSTransformer(Transformer):
     """Featuretools DFS component that generates features for the input features.
 
-    Arguments:
+    Args:
         index (string): The name of the column that contains the indices. If no column with this name exists,
             then featuretools.EntitySet() creates a column with this name to serve as the index column. Defaults to 'index'.
         random_seed (int): Seed for the random number generator. Defaults to 0.
@@ -31,7 +32,7 @@ class DFSTransformer(Transformer):
         super().__init__(parameters=parameters, random_seed=random_seed)
 
     def _make_entity_set(self, X):
-        """Helper method that creates and returns the entity set given the input data"""
+        """Helper method that creates and returns the entity set given the input data."""
         ft_es = EntitySet()
         if self.index not in X.columns:
             es = ft_es.entity_from_dataframe(
@@ -46,9 +47,9 @@ class DFSTransformer(Transformer):
     def fit(self, X, y=None):
         """Fits the DFSTransformer Transformer component.
 
-        Arguments:
-            X (pd.DataFrame, np.array): The input data to transform, of shape [n_samples, n_features]
-            y (pd.Series, np.ndarray, optional): The target training data of length [n_samples]
+        Args:
+            X (pd.DataFrame, np.array): The input data to transform, of shape [n_samples, n_features].
+            y (pd.Series): The target training data of length [n_samples].
 
         Returns:
             self
@@ -64,7 +65,7 @@ class DFSTransformer(Transformer):
     def transform(self, X, y=None):
         """Computes the feature matrix for the input X using featuretools' dfs algorithm.
 
-        Arguments:
+        Args:
             X (pd.DataFrame or np.ndarray): The input training data to transform. Has shape [n_samples, n_features]
             y (pd.Series, optional): Ignored.
 
