@@ -1,3 +1,4 @@
+"""Component that removes trends from time series by fitting a polynomial to the data."""
 import pandas as pd
 from skopt.space import Integer
 
@@ -10,7 +11,7 @@ from evalml.utils import import_or_raise, infer_feature_types
 class PolynomialDetrender(TargetTransformer):
     """Removes trends from time series by fitting a polynomial to the data.
 
-    Arguments:
+    Args:
         degree (int): Degree for the polynomial. If 1, linear model is fit to the data.
             If 2, quadratic model is fit, etc. Defaults to 1.
         random_seed (int): Seed for the random number generator. Defaults to 0.
@@ -49,12 +50,15 @@ class PolynomialDetrender(TargetTransformer):
     def fit(self, X, y=None):
         """Fits the PolynomialDetrender.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, optional): Ignored.
             y (pd.Series): Target variable to detrend.
 
         Returns:
             self
+
+        Raises:
+            ValueError: If y is None.
         """
         if y is None:
             raise ValueError("y cannot be None for PolynomialDetrender!")
@@ -65,7 +69,7 @@ class PolynomialDetrender(TargetTransformer):
     def transform(self, X, y=None):
         """Removes fitted trend from target variable.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, optional): Ignored.
             y (pd.Series): Target variable to detrend.
 
@@ -83,7 +87,7 @@ class PolynomialDetrender(TargetTransformer):
     def fit_transform(self, X, y=None):
         """Removes fitted trend from target variable.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, optional): Ignored.
             y (pd.Series): Target variable to detrend.
 
@@ -96,13 +100,15 @@ class PolynomialDetrender(TargetTransformer):
     def inverse_transform(self, y):
         """Adds back fitted trend to target variable.
 
-        Arguments:
-            X (pd.DataFrame, optional): Ignored.
+        Args:
             y (pd.Series): Target variable.
 
         Returns:
             tuple of pd.DataFrame, pd.Series: The first element are the input features returned without modification.
                 The second element is the target variable y with the trend added back.
+
+        Raises:
+            ValueError: If y is None.
         """
         if y is None:
             raise ValueError("y cannot be None for PolynomialDetrender!")
