@@ -414,7 +414,8 @@ def test_describe_component():
                 "max_depth": 3,
                 "min_child_weight": 1,
                 "n_estimators": 75,
-                "n_jobs": -1,
+                "n_jobs": 12,
+                "eval_metric": "logloss",
             },
         }
         assert xgb_regressor.describe(return_dict=True) == {
@@ -424,7 +425,7 @@ def test_describe_component():
                 "max_depth": 3,
                 "min_child_weight": 1,
                 "n_estimators": 75,
-                "n_jobs": -1,
+                "n_jobs": 12,
             },
         }
     except ImportError:
