@@ -41,6 +41,7 @@ def test_featurizer_only_text(text_df):
 def test_featurizer_with_nontext(text_df):
     X = text_df
     X["col_3"] = [73.7, 67.213, 92]
+    X.ww.init(logical_types={"col_1": "NaturalLanguage", "col_2": "NaturalLanguage"})
     tf = TextFeaturizer()
 
     tf.fit(X)
@@ -147,6 +148,7 @@ def test_no_null_output():
             ],
         }
     )
+    X.ww.init(logical_types={"col_1": "NaturalLanguage", "col_2": "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
     X_t = tf.transform(X)
@@ -170,6 +172,8 @@ def test_index_col_names():
             ],
         ]
     )
+    X = pd.DataFrame(X)
+    X.ww.init(logical_types={0: "NaturalLanguage", 1: "NaturalLanguage"})
     tf = TextFeaturizer()
 
     tf.fit(X)
@@ -210,6 +214,7 @@ def test_float_col_names():
             ],
         }
     )
+    X.ww.init(logical_types={4.75: "NaturalLanguage", -1: "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
     expected_col_names = set(
@@ -249,6 +254,7 @@ def test_output_null():
             ],
         }
     )
+    X.ww.init(logical_types={"col_1": "NaturalLanguage", "col_2": "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
     X_t = tf.transform(X)
@@ -265,6 +271,7 @@ def test_diversity_primitive_output():
             ]
         }
     )
+    X.ww.init(logical_types={"diverse": "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
 
@@ -284,6 +291,7 @@ def test_lsa_primitive_output():
             ]
         }
     )
+    X.ww.init(logical_types={"lsa": "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
 
@@ -300,7 +308,9 @@ def test_featurizer_custom_types(text_df):
     # force one of the two provided columns to be a user-specified type.
     # if the output contains text features for col_2, then the text featurizer didn't pass the right
     # ww types to LSA, because LSA still thought col_2 was natural language even though the user said otherwise.
-    X = infer_feature_types(text_df, {"col_2": "categorical"})
+    X = infer_feature_types(
+        pd.DataFrame(text_df), {"col_1": "NaturalLanguage", "col_2": "categorical"}
+    )
     tf = TextFeaturizer()
     tf.fit(X)
 
@@ -339,6 +349,7 @@ def test_mean_characters_primitive_output():
             ]
         }
     )
+    X.ww.init(logical_types={"mean_characters": "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
 
@@ -361,6 +372,7 @@ def test_polarity_primitive_output():
             ]
         }
     )
+    X.ww.init(logical_types={"polarity": "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
 
@@ -415,7 +427,7 @@ def test_text_featurizer_woodwork_custom_overrides_returned_by_components(X_df):
     for logical_type in override_types:
         try:
             X = X_df.copy()
-            X.ww.init(logical_types={0: logical_type})
+            X.ww.init(logical_types={0: logical_type, "text col": "NaturalLanguage"})
         except ww.exceptions.TypeConversionError:
             continue
 
@@ -443,7 +455,85 @@ def test_text_featurizer_sets_max_depth_1(mock_dfs):
             ]
         }
     )
+    X.ww.init(logical_types={"polarity": "NaturalLanguage"})
     tf = TextFeaturizer()
     tf.fit(X)
     _, kwargs = mock_dfs.call_args
     assert kwargs["max_depth"] == 1
+
+
+@pytest.mark.parametrize("nones", [np.nan, pd.NA, None])
+def test_nan_allowed(nones):
+    X = pd.DataFrame(
+        {
+            "col_1": [
+                "I'm singing in the rain! Just singing in the rain, what a glorious feeling, I'm happy again!",
+                "In sleep he sang to me, in dreams he came... That voice which calls to me, and speaks my name.",
+                "I'm gonna be the main event, like no king was before! I'm brushing up on looking down, I'm working on my ROAR!",
+                "",
+                nones,
+            ],
+            "col_2": [
+                "do you hear the people sing? Singing the songs of angry men\n\tIt is the music of a people who will NOT be slaves again!",
+                "I dreamed a dream in days gone by, when hope was high and life worth living Red, the blood of angry men - black, the dark of ages past",
+                ":)",
+                "None",
+                "",
+            ],
+        }
+    )
+    X.ww.init(logical_types={"col_1": "NaturalLanguage", "col_2": "NaturalLanguage"})
+    tf = TextFeaturizer()
+    tf.fit(X)
+    X_t = tf.transform(X)
+    cols = [
+        "LSA(col_1)[0]",
+        "LSA(col_1)[1]",
+        "DIVERSITY_SCORE(col_1)",
+        "MEAN_CHARACTERS_PER_WORD(col_1)",
+        "POLARITY_SCORE(col_1)",
+    ]
+    # find the columns that should be null
+    assert all(X_t[cols].iloc[4, :].isnull())
+    # these columns should not have any null values
+    assert not X_t[cols].iloc[:4, :].isnull().any().any()
+    assert not X_t[X_t.columns.difference(cols)].isnull().any().any()
+
+
+@pytest.mark.parametrize("nones", [np.nan, pd.NA, None])
+def test_multiple_nan_allowed(nones):
+    X = pd.DataFrame(
+        {
+            "col_1": [
+                "I'm singing in the rain! Just singing in the rain, what a glorious feeling, I'm happy again!",
+                "In sleep he sang to me, in dreams he came... That voice which calls to me, and speaks my name.",
+                "",
+                None,
+            ],
+            "col_2": [
+                "do you hear the people sing? Singing the songs of angry men\n\tIt is the music of a people who will NOT be slaves again!",
+                "I dreamed a dream in days gone by, when hope was high and life worth living Red, the blood of angry men - black, the dark of ages past",
+                ":)",
+                nones,
+            ],
+            "col_3": [1, 2, 3, 1],
+        }
+    )
+    X.ww.init(logical_types={"col_1": "NaturalLanguage", "col_2": "NaturalLanguage"})
+    tf = TextFeaturizer()
+    tf.fit(X)
+    X_t = tf.transform(X)
+    col_names = [
+        "LSA({})[0]",
+        "LSA({})[1]",
+        "DIVERSITY_SCORE({})",
+        "MEAN_CHARACTERS_PER_WORD({})",
+        "POLARITY_SCORE({})",
+    ]
+    cols = [c.format(n) for n in ["col_1", "col_2"] for c in col_names]
+    # find the columns that should be null
+    assert all(X_t[cols].iloc[3, :].isnull())
+    # these columns should not have any null values
+    assert not X_t[cols].iloc[:3, :].isnull().any().any()
+    assert not X_t[X_t.columns.difference(cols)].isnull().any().any()
+    assert all([pd.api.types.is_numeric_dtype(types) for types in X_t[cols].dtypes])
