@@ -157,7 +157,12 @@ def test_make_pipeline(
             parameters = {}
             if is_time_series(problem_type):
                 parameters = {
-                    "pipeline": {"date_index": None, "gap": 1, "max_delay": 1},
+                    "pipeline": {
+                        "date_index": None,
+                        "gap": 1,
+                        "max_delay": 1,
+                        "forecast_horizon": 3,
+                    },
                 }
 
             pipeline = make_pipeline(X, y, estimator_class, problem_type, parameters)
