@@ -13,7 +13,7 @@ from evalml.utils.cli_utils import (
     get_sys_info,
     print_deps,
     print_info,
-    print_sys_info
+    print_sys_info,
 )
 
 
@@ -23,10 +23,12 @@ def current_dir():
 
 
 def get_core_requirements(current_dir):
-    reqs_path = os.path.join(current_dir, pathlib.Path('..', '..', '..', 'core-requirements.txt'))
-    lines = open(reqs_path, 'r').readlines()
-    lines = [line for line in lines if '-r ' not in line]
-    reqs = requirements.parse(''.join(lines))
+    reqs_path = os.path.join(
+        current_dir, pathlib.Path("..", "..", "..", "core-requirements.txt")
+    )
+    lines = open(reqs_path, "r").readlines()
+    lines = [line for line in lines if "-r " not in line]
+    reqs = requirements.parse("".join(lines))
     reqs_names = [req.name for req in reqs]
     return reqs_names
 
@@ -40,7 +42,7 @@ def test_print_cli_cmd():
 
 def test_print_cli_info_cmd(caplog):
     runner = CliRunner()
-    result = runner.invoke(cli, ['info'])
+    result = runner.invoke(cli, ["info"])
     assert result.exit_code == 0
     assert "EvalML version:" in caplog.text
     assert "EvalML installation directory:" in caplog.text
@@ -74,15 +76,25 @@ def test_print_deps_info(caplog, current_dir):
 
 def test_sys_info():
     sys_info = get_sys_info()
-    info_keys = ["python", "python-bits", "OS",
-                 "OS-release", "machine", "processor",
-                 "byteorder", "LC_ALL", "LANG", "LOCALE",
-                 "# of CPUS", "Available memory"]
+    info_keys = [
+        "python",
+        "python-bits",
+        "OS",
+        "OS-release",
+        "machine",
+        "processor",
+        "byteorder",
+        "LC_ALL",
+        "LANG",
+        "LOCALE",
+        "# of CPUS",
+        "Available memory",
+    ]
     found_keys = [k for k, _ in sys_info]
     assert set(info_keys).issubset(found_keys)
 
 
-@patch('platform.uname')
+@patch("platform.uname")
 def test_sys_info_error(mock_uname):
     mock_uname.side_effects = ValueError()
     assert len(get_sys_info()) == 0
@@ -96,5 +108,5 @@ def test_installed_packages(current_dir):
 
 
 def test_get_evalml_root(current_dir):
-    root = os.path.abspath(os.path.join(current_dir, '..', ".."))
+    root = os.path.abspath(os.path.join(current_dir, "..", ".."))
     assert get_evalml_root() == root
