@@ -1,3 +1,4 @@
+"""General utility methods."""
 import importlib
 import logging
 import os
@@ -18,13 +19,19 @@ logger = logging.getLogger(__name__)
 
 
 def import_or_raise(library, error_msg=None, warning=False):
-    """Attempts to import the requested library by name.
-    If the import fails, raises an ImportError or warning.
+    """Attempts to import the requested library by name. If the import fails, raises an ImportError or warning.
 
-    Arguments:
-        library (str): the name of the library
-        error_msg (str): error message to return if the import fails
-        warning (bool): if True, import_or_raise gives a warning instead of ImportError. Defaults to False.
+    Args:
+        library (str): The name of the library.
+        error_msg (str): Rrror message to return if the import fails.
+        warning (bool): If True, import_or_raise gives a warning instead of ImportError. Defaults to False.
+
+    Returns:
+        Returns the library if importing succeeded.
+
+    Raises:
+        ImportError: If attempting to import the library fails because the library is not installed.
+        Exception: If importing the library fails.
     """
     try:
         return importlib.import_module(library)
@@ -76,8 +83,14 @@ SEED_BOUNDS = namedtuple("SEED_BOUNDS", ("min_bound", "max_bound"))(0, 2 ** 31 -
 def get_random_state(seed):
     """Generates a numpy.random.RandomState instance using seed.
 
-    Arguments:
-        seed (None, int, np.random.RandomState object): seed to use to generate numpy.random.RandomState. Must be between SEED_BOUNDS.min_bound and SEED_BOUNDS.max_bound, inclusive. Otherwise, an exception will be thrown.
+    Args:
+        seed (None, int, np.random.RandomState object): seed to use to generate numpy.random.RandomState. Must be between SEED_BOUNDS.min_bound and SEED_BOUNDS.max_bound, inclusive.
+
+    Raises:
+        ValueError: If the input seed is not within the acceptable range.
+
+    Returns:
+        A numpy.random.RandomState instance.
     """
     if isinstance(seed, (int, np.integer)) and (
         seed < SEED_BOUNDS.min_bound or SEED_BOUNDS.max_bound < seed
@@ -97,13 +110,16 @@ def get_random_seed(
 
     To protect against invalid input to a particular library's random number generator, if an int value is provided, and it is outside the bounds "[min_bound, max_bound)", the value will be projected into the range between the min_bound (inclusive) and max_bound (exclusive) using modular arithmetic.
 
-    Arguments:
+    Args:
         random_state (int, numpy.random.RandomState): random state
         min_bound (None, int): if not default of None, will be min bound when generating seed (inclusive). Must be less than max_bound.
         max_bound (None, int): if not default of None, will be max bound when generating seed (exclusive). Must be greater than min_bound.
 
     Returns:
-        int: seed for random number generator
+        int: Seed for random number generator
+
+    Raises:
+        ValueError: If boundaries are not valid.
     """
     if not min_bound < max_bound:
         raise ValueError(
@@ -122,7 +138,6 @@ class classproperty:
     """Allows function to be accessed as a class level property.
 
     Example:
-
     .. code-block::
 
         class LogisticRegressionBinaryPipeline(PipelineBase):
@@ -144,19 +159,19 @@ class classproperty:
         self.func = func
 
     def __get__(self, _, klass):
+        """Get property value."""
         return self.func(klass)
 
 
 def _get_subclasses(base_class):
     """Gets all of the leaf nodes in the hiearchy tree for a given base class.
 
-    Arguments:
+    Args:
         base_class (abc.ABCMeta): Class to find all of the children for.
 
     Returns:
         subclasses (list): List of all children that are not base classes.
     """
-
     classes_to_check = base_class.__subclasses__()
     subclasses = []
 
@@ -186,13 +201,10 @@ _not_used_in_automl = {
 
 
 def get_importable_subclasses(base_class, used_in_automl=True):
-    """Get importable subclasses of a base class. Used to list all of our
-    estimators, transformers, components and pipelines dynamically.
+    """Get importable subclasses of a base class. Used to list all of our estimators, transformers, components and pipelines dynamically.
 
-    Arguments:
+    Args:
         base_class (abc.ABCMeta): Base class to find all of the subclasses for.
-        args (list): Args used to instantiate the subclass. [{}] for a pipeline, and [] for
-            all other classes.
         used_in_automl: Not all components/pipelines/estimators are used in automl search. If True,
             only include those subclasses that are used in the search. This would mean excluding classes related to
             ExtraTrees, ElasticNet, and Baseline estimators.
@@ -222,11 +234,9 @@ def get_importable_subclasses(base_class, used_in_automl=True):
 
 
 def _rename_column_names_to_numeric(X, flatten_tuples=True):
-    """Used in LightGBM and XGBoost estimator classes to rename column names
-    when the input is a pd.DataFrame in case it has column names that contain symbols ([, ], <)
-    that these estimators cannot natively handle.
+    """Used in LightGBM and XGBoost estimator classes to rename column names when the input is a pd.DataFrame in case it has column names that contain symbols ([, ], <) that these estimators cannot natively handle.
 
-    Arguments:
+    Args:
         X (pd.DataFrame): The input training data of shape [n_samples, n_features]
         flatten_tuples (bool): Whether to flatten MultiIndex or tuple column names. LightGBM cannot handle columns with tuple names.
 
@@ -252,13 +262,10 @@ def _rename_column_names_to_numeric(X, flatten_tuples=True):
 
 
 def jupyter_check():
-    """Get whether or not the code is being run in a Ipython environment (such as Jupyter Notebook or Jupyter Lab)
-
-    Arguments:
-        None
+    """Get whether or not the code is being run in a Ipython environment (such as Jupyter Notebook or Jupyter Lab).
 
     Returns:
-        Boolean: True if Ipython, False otherwise
+        boolean: True if Ipython, False otherwise.
     """
     try:
         ipy = import_or_raise("IPython")
@@ -268,10 +275,10 @@ def jupyter_check():
 
 
 def safe_repr(value):
-    """Convert the given value into a string that can safely be used for repr
+    """Convert the given value into a string that can safely be used for repr.
 
-    Arguments:
-        value: the item to convert
+    Args:
+        value: The item to convert
 
     Returns:
         String representation of the value
@@ -285,9 +292,9 @@ def safe_repr(value):
 
 
 def is_all_numeric(df):
-    """Checks if the given DataFrame contains only numeric values
+    """Checks if the given DataFrame contains only numeric values.
 
-    Arguments:
+    Args:
         df (pd.DataFrame): The DataFrame to check data types of.
 
     Returns:
@@ -305,8 +312,9 @@ def is_all_numeric(df):
 def pad_with_nans(pd_data, num_to_pad):
     """Pad the beginning num_to_pad rows with nans.
 
-    Arguments:
+    Args:
         pd_data (pd.DataFrame or pd.Series): Data to pad.
+        num_to_pad (int): Number of nans to pad.
 
     Returns:
         pd.DataFrame or pd.Series
@@ -330,7 +338,7 @@ def pad_with_nans(pd_data, num_to_pad):
 def _get_rows_without_nans(*data):
     """Compute a boolean array marking where all entries in the data are non-nan.
 
-    Arguments:
+    Args:
         *data (sequence of pd.Series or pd.DataFrame)
 
     Returns:
@@ -355,13 +363,12 @@ def _get_rows_without_nans(*data):
 def drop_rows_with_nans(*pd_data):
     """Drop rows that have any NaNs in all dataframes or series.
 
-    Arguments:
-        *pd_data (sequence of pd.Series or pd.DataFrame or None)
+    Args:
+        *pd_data: sequence of pd.Series or pd.DataFrame or None
 
     Returns:
         list of pd.DataFrame or pd.Series or None
     """
-
     mask = _get_rows_without_nans(*pd_data)
 
     def _subset(pd_data):
@@ -375,7 +382,7 @@ def drop_rows_with_nans(*pd_data):
 def _file_path_check(filepath=None, format="png", interactive=False, is_plotly=False):
     """Helper function to check the filepath being passed.
 
-    Arguments:
+    Args:
         filepath (str or Path, optional): Location to save file.
         format (str): Extension for figure to be saved as. Defaults to 'png'.
         interactive (bool, optional): If True and fig is of type plotly.Figure, sets the format to 'html'.
@@ -410,13 +417,13 @@ def save_plot(
 ):
     """Saves fig to filepath if specified, or to a default location if not.
 
-    Arguments:
+    Args:
         fig (Figure): Figure to be saved.
         filepath (str or Path, optional): Location to save file. Default is with filename "test_plot".
         format (str): Extension for figure to be saved as. Ignored if interactive is True and fig
-        is of type plotly.Figure. Defaults to 'png'.
+            is of type plotly.Figure. Defaults to 'png'.
         interactive (bool, optional): If True and fig is of type plotly.Figure, saves the fig as interactive
-        instead of static, and format will be set to 'html'. Defaults to False.
+            instead of static, and format will be set to 'html'. Defaults to False.
         return_filepath (bool, optional): Whether to return the final filepath the image is saved to. Defaults to False.
 
     Returns:
@@ -478,7 +485,7 @@ def save_plot(
 def deprecate_arg(old_arg, new_arg, old_value, new_value):
     """Helper to raise warnings when a deprecated arg is used.
 
-    Arguments:
+    Args:
         old_arg (str): Name of old/deprecated argument.
         new_arg (str): Name of new argument.
         old_value (Any): Value the user passed in for the old argument.
